@@ -10,6 +10,7 @@ class AlipayMarketingActivityConsultModel(object):
 
     def __init__(self):
         self._consult_activity_info_list = None
+        self._merchant_access_mode = None
         self._merchant_id = None
         self._user_id = None
 
@@ -27,6 +28,13 @@ class AlipayMarketingActivityConsultModel(object):
                 else:
                     self._consult_activity_info_list.append(ConsultActivityInfo.from_alipay_dict(i))
     @property
+    def merchant_access_mode(self):
+        return self._merchant_access_mode
+
+    @merchant_access_mode.setter
+    def merchant_access_mode(self, value):
+        self._merchant_access_mode = value
+    @property
     def merchant_id(self):
         return self._merchant_id
 
@@ -54,6 +62,11 @@ class AlipayMarketingActivityConsultModel(object):
                 params['consult_activity_info_list'] = self.consult_activity_info_list.to_alipay_dict()
             else:
                 params['consult_activity_info_list'] = self.consult_activity_info_list
+        if self.merchant_access_mode:
+            if hasattr(self.merchant_access_mode, 'to_alipay_dict'):
+                params['merchant_access_mode'] = self.merchant_access_mode.to_alipay_dict()
+            else:
+                params['merchant_access_mode'] = self.merchant_access_mode
         if self.merchant_id:
             if hasattr(self.merchant_id, 'to_alipay_dict'):
                 params['merchant_id'] = self.merchant_id.to_alipay_dict()
@@ -73,6 +86,8 @@ class AlipayMarketingActivityConsultModel(object):
         o = AlipayMarketingActivityConsultModel()
         if 'consult_activity_info_list' in d:
             o.consult_activity_info_list = d['consult_activity_info_list']
+        if 'merchant_access_mode' in d:
+            o.merchant_access_mode = d['merchant_access_mode']
         if 'merchant_id' in d:
             o.merchant_id = d['merchant_id']
         if 'user_id' in d:
