@@ -19,6 +19,7 @@ class AlipayTradePrecreateModel(object):
         self._body = None
         self._business_params = None
         self._buyer_logon_id = None
+        self._code_type = None
         self._disable_pay_channels = None
         self._discountable_amount = None
         self._enable_pay_channels = None
@@ -31,6 +32,7 @@ class AlipayTradePrecreateModel(object):
         self._passback_params = None
         self._product_code = None
         self._qr_code_timeout_express = None
+        self._query_options = None
         self._royalty_info = None
         self._seller_id = None
         self._settle_info = None
@@ -75,6 +77,13 @@ class AlipayTradePrecreateModel(object):
     def buyer_logon_id(self, value):
         self._buyer_logon_id = value
     @property
+    def code_type(self):
+        return self._code_type
+
+    @code_type.setter
+    def code_type(self, value):
+        self._code_type = value
+    @property
     def disable_pay_channels(self):
         return self._disable_pay_channels
 
@@ -171,6 +180,16 @@ class AlipayTradePrecreateModel(object):
     def qr_code_timeout_express(self, value):
         self._qr_code_timeout_express = value
     @property
+    def query_options(self):
+        return self._query_options
+
+    @query_options.setter
+    def query_options(self, value):
+        if isinstance(value, list):
+            self._query_options = list()
+            for i in value:
+                self._query_options.append(i)
+    @property
     def royalty_info(self):
         return self._royalty_info
 
@@ -280,6 +299,11 @@ class AlipayTradePrecreateModel(object):
                 params['buyer_logon_id'] = self.buyer_logon_id.to_alipay_dict()
             else:
                 params['buyer_logon_id'] = self.buyer_logon_id
+        if self.code_type:
+            if hasattr(self.code_type, 'to_alipay_dict'):
+                params['code_type'] = self.code_type.to_alipay_dict()
+            else:
+                params['code_type'] = self.code_type
         if self.disable_pay_channels:
             if hasattr(self.disable_pay_channels, 'to_alipay_dict'):
                 params['disable_pay_channels'] = self.disable_pay_channels.to_alipay_dict()
@@ -345,6 +369,16 @@ class AlipayTradePrecreateModel(object):
                 params['qr_code_timeout_express'] = self.qr_code_timeout_express.to_alipay_dict()
             else:
                 params['qr_code_timeout_express'] = self.qr_code_timeout_express
+        if self.query_options:
+            if isinstance(self.query_options, list):
+                for i in range(0, len(self.query_options)):
+                    element = self.query_options[i]
+                    if hasattr(element, 'to_alipay_dict'):
+                        self.query_options[i] = element.to_alipay_dict()
+            if hasattr(self.query_options, 'to_alipay_dict'):
+                params['query_options'] = self.query_options.to_alipay_dict()
+            else:
+                params['query_options'] = self.query_options
         if self.royalty_info:
             if hasattr(self.royalty_info, 'to_alipay_dict'):
                 params['royalty_info'] = self.royalty_info.to_alipay_dict()
@@ -415,6 +449,8 @@ class AlipayTradePrecreateModel(object):
             o.business_params = d['business_params']
         if 'buyer_logon_id' in d:
             o.buyer_logon_id = d['buyer_logon_id']
+        if 'code_type' in d:
+            o.code_type = d['code_type']
         if 'disable_pay_channels' in d:
             o.disable_pay_channels = d['disable_pay_channels']
         if 'discountable_amount' in d:
@@ -439,6 +475,8 @@ class AlipayTradePrecreateModel(object):
             o.product_code = d['product_code']
         if 'qr_code_timeout_express' in d:
             o.qr_code_timeout_express = d['qr_code_timeout_express']
+        if 'query_options' in d:
+            o.query_options = d['query_options']
         if 'royalty_info' in d:
             o.royalty_info = d['royalty_info']
         if 'seller_id' in d:
